Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/bluefruitconnect_simpletest.py
    :caption: examples/bluefruitconnect_simpletest.py
    :linenos:

This example demonstrates receiving button presses from the Control Pad.

.. literalinclude:: ../examples/bluefruitconnect_controlpad.py
    :caption: examples/bluefruitconnect_controlpad.py
    :linenos:

This example demonstrates receiving sensor data from the Controller.

.. literalinclude:: ../examples/bluefruitconnect_sensors.py
    :caption: examples/bluefruitconnect_sensors.py
    :linenos:

This example demonstrates receiving text from the UART interface.

.. literalinclude:: ../examples/bluefruitconnect_uart.py
    :caption: examples/bluefruitconnect_uart.py
    :linenos:
